@@ -9,12 +9,11 @@ NULL
   env <- parent.frame()
   lhs <- substitute(lhs)
 
-  tryCatch({
+  isnull <- tryCatch({
     is.null(eval(lhs, envir = env))
   }, error = function(e){
     return(TRUE)
-  }) ->
-    isnull
+  })
 
   if(isnull){
     eval(as.call(list( quote(`<-`), lhs, value )), envir = env)
