@@ -2,5 +2,5 @@ library(testthat)
 library(ravetools)
 
 # Make sure use 2 cores to comply with the CRAN policy
-RcppParallel::setThreadOptions(numThreads = 2L)
+ravetools_threads(n_threads = 2L)
 test_check("ravetools")
